@@ -12,7 +12,7 @@ from .i18n import _
 RUNNING_AS_ROOT = os.geteuid() == 0
 
 
-VERSION = '1.6.11-dev'
+VERSION = '1.6.12-dev'
 
 _USER_CACHE_HOME = os.environ.get(
     "XDG_CACHE_HOME",
@@ -235,6 +235,14 @@ CONFIG_SCHEMA: Dict[str, Any] = {
             'type': 'str',
             'default': '',
         },
+        'AurHttpProxy': {
+            'type': 'str',
+            'default': '',
+        },
+        'AurHttpsProxy': {
+            'type': 'str',
+            'default': '',
+        },
     },
 }
 
